@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2007,2008,2009,2010,2011,2012,2013,2014 Rolf Eike Beer <kde@opensource.sf-tec.de>
+ * Copyright (C) 2007,2008,2009,2010,2011,2012,2013,2014,2016 Rolf Eike Beer <kde@opensource.sf-tec.de>
  */
 
 /***************************************************************************
@@ -13,11 +13,11 @@
 #ifndef GPGPROC_H
 #define GPGPROC_H
 
-#include <QString>
-
-#include "kgpgcompiler.h"
 #include "klinebufferedprocess.h"
 
+#include <QByteArray>
+#include <QString>
+
 class QStringList;
 
 /**
@@ -155,24 +155,29 @@ public:
      * @return the error message GnuPG gave out (if any)
      */
     static QString getGpgStartupError(const QString &binary);
+
+    /**
+     * @brief run GnuPG and let it return it's config output
+     * @param binary the GnuPG binary to run
+     * @param key if only fields of a given type should be returned
+     * @return all matching fields
+     *
+     * In case a key is given the key is already removed from the
+     * returned lines.
+     */
+    static QStringList getGgpParsedConfig(const QString &binary, const QByteArray &key = QByteArray());
 signals:
     /**
      * Emitted when the process is ready for reading.
      * The signal is only emitted if at least one complete line of data is ready.
-     * @param p the process that emitted the signal
      */
     void readReady();
 
     /**
      * Emitted when the process has finished
-     * @param p the process that emitted the signal
      */
     void processExited();
 
-protected slots:
-    void finished();
-    void received();
-
 private:
     QByteArray m_codec;
 };
